==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/Home/Dashlets/RSSDashlet/RSSDashlet.en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/





$dashletStrings['RSSDashlet'] = array('LBL_TITLE'            => 'News Feed',
                                         'LBL_DESCRIPTION'      => 'News Feed',
                                         'LBL_SAVING'           => 'Parsing ...',
                                         'LBL_SAVED'            => 'Complete',
                                         'LBL_AUTO_SCROLL'      => 'Auto Scroll',
                                          'LBL_SCROLL_SPEED'      => 'Scroll Speed (%)',
                                         'LBL_CONFIGURE_TITLE'  => 'Title',
                                         'LBL_CONFIGURE_HEIGHT' => 'Height (1 - 300)',
                                         'LBL_CONFIGURE_RSSURL' => 'RSS Url',
                                         'LBL_DBLCLICK_HELP'    => '',
                                         'ERR_LOADING_FEED'     => 'Failed loading RSS Feed',
                                         );
?>

==> SugarCE-6.2.1.zip: SugarCE-Full-6.2.1/modules/Home/Dashlets/RSSDashlet/RSSDashlet.en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/





$dashletStrings['RSSDashlet'] = array('LBL_TITLE'            => 'News Feed',
                                         'LBL_DESCRIPTION'      => 'News Feed',
                                         'LBL_SAVING'           => 'Parsing ...',
                                         'LBL_SAVED'            => 'Complete',
                                         'LBL_AUTO_SCROLL'      => 'Auto Scroll',
                                          'LBL_SCROLL_SPEED'      => 'Scroll Speed (%)',
                                         'LBL_CONFIGURE_TITLE'  => 'Title',
                                         'LBL_CONFIGURE_HEIGHT' => 'Height (1 - 300)',
                                         'LBL_CONFIGURE_RSSURL' => 'RSS Url',
                                         'LBL_DBLCLICK_HELP'    => '',
                                         'ERR_LOADING_FEED'     => 'Failed loading RSS Feed',
                                         );
?>
